package ca.recrown.islandsurvivalcraft.interaction.commands.runnables;

import java.util.concurrent.CompletableFuture;

import org.bukkit.command.CommandSender;

import ca.recrown.islandsurvivalcraft.IslandSurvivalCraft;

public interface CommandRunnable {
    /**
     * @return a string that gives users an idea of what this command does. Should be short and not include details on arguments.
     */
    public String getDescription();

    /**
     * @return A more detailed description. Doesn't need to contain information already present in normal description as will print with that one. This string should describe proper usage arguments required.
     */
    public String getDetailedDescription();

    /**
     * Invokes this particular command.
     * Should check for correct arguments.
     * @param sender The sender of this command.
     * @param args The arguments given for this command. May be length of 0, in which case there were no arguments.
     * @return The completable future for the command. The completable future should ultimately return a message in the form of the string letting the user know the the completed execution, or a failure message.
     */
    public CompletableFuture<String> invoke(CommandSender sender, String[] args);

    /**
     * Initializes the command. Is run the first time this command is run.
     * @param islandSurvivalCraft
     */
    public void initialize(IslandSurvivalCraft islandSurvivalCraft);
}